@@ -156,6 +156,7 @@ setup_mappings() {
 
 # Use the newest version of the Rust toolchain
 rustup update
+MSRV=1.66.0
 
 # Parse arguments
 NO_CARGO_CLEAN=
@@ -247,12 +248,13 @@ fi
 git submodule update --init
 
 if [ "$PROVIDER_NAME" = "coverage" ]; then
-    rustup toolchain install 1.57.0
+    rustup toolchain install ${MSRV}
     PROVIDERS="trusted-service mbed-crypto tpm pkcs11"
     EXCLUDES="fuzz/*,e2e_tests/*,src/providers/cryptoauthlib/*,src/authenticators/jwt_svid_authenticator/*"
     UNIT_TEST_FEATURES="unix-peer-credentials-authenticator,direct-authenticator"
     # Install tarpaulin
-    cargo +1.57.0 install cargo-tarpaulin
+    # TODO: Stop using the --version parameter when MSRV is upgraded.
+    cargo +${MSRV} install cargo-tarpaulin --version 0.26.1
 
     mkdir -p reports
 
@@ -268,7 +270,7 @@ if [ "$PROVIDER_NAME" = "coverage" ]; then
         cp -r $(pwd)/e2e_tests/fake_mappings/* mappings
 
         # Start service
-        RUST_LOG=info cargo +1.57.0 tarpaulin --out Xml --forward --command build --exclude-files="$EXCLUDES" \
+        RUST_LOG=info cargo +${MSRV} tarpaulin --out Xml --forward --command build --exclude-files="$EXCLUDES" \
             --output-dir $(pwd)/reports/$provider --features="$provider-provider,direct-authenticator" \
             --run-types bins --timeout 3600 -- -c $CONFIG_PATH &
         wait_for_service
@@ -286,17 +288,18 @@ if [ "$PROVIDER_NAME" = "coverage" ]; then
         fi
 
         # Start service
-        RUST_LOG=info cargo +1.57.0 tarpaulin --out Xml --forward --command build --exclude-files="$EXCLUDES" \
+        RUST_LOG=info cargo +${MSRV} tarpaulin --out Xml --forward --command build --exclude-files="$EXCLUDES" \
             --output-dir $(pwd)/reports/$provider --features="$provider-provider,direct-authenticator" \
             --run-types bins --timeout 3600 -- -c $CONFIG_PATH &
         wait_for_service
 
         run_key_mappings_tests
+        stop_service
     done
 
     # Run unit tests
     mkdir -p reports/unit
-    cargo +1.57.0 tarpaulin --tests --out Xml --features=$UNIT_TEST_FEATURES --exclude-files="$EXCLUDES" --output-dir $(pwd)/reports/unit
+    cargo +${MSRV} tarpaulin --tests --out Xml --features=$UNIT_TEST_FEATURES --exclude-files="$EXCLUDES" --output-dir $(pwd)/reports/unit
 
     exit 0
 fi
@@ -330,11 +333,10 @@ if [ "$PROVIDER_NAME" = "cargo-check" ]; then
     # - RHEL-9 (intend to support in the future)
     # - openSUSE Tumbleweed
     # - openSUSE Leap 15.4
-    # The oldest is currently in RHEL9, is 1.58.1.
 
-    rustup toolchain install 1.58.1
-    # The "jwt-svid-authenticator" can not be compiled on 1.58.1
-    RUST_BACKTRACE=1 cargo +1.58.1 check --release --features=all-providers,direct-authenticator,unix-peer-credentials-authenticator
+    rustup toolchain install ${MSRV}
+    # TODO: The "jwt-svid-authenticator" is currently not being used.
+    RUST_BACKTRACE=1 cargo +${MSRV} check --release --features=all-providers,direct-authenticator,unix-peer-credentials-authenticator
 
     # Latest stable
     rustup toolchain install stable
